@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-07-15 11:30:45
-@LastEditTime: 2022-02-21 10:38:06
+@LastEditTime: 2022-03-09 17:18:30
 @LastEditors: HuangJianYi
 @Description: 公共handler模块
 """
@@ -12,6 +12,7 @@ import random
 import decimal
 import hashlib
 from copy import deepcopy
+from unittest import result
 from asq.initiators import query
 from urllib.parse import parse_qs, urlparse
 
@@ -25,6 +26,8 @@ from seven_cloudapp_frame.models.user_base_model import *
 from seven_cloudapp_frame.models.db_models.app.app_info_model import *
 from seven_cloudapp_frame.models.db_models.act.act_info_model import *
 from seven_cloudapp_frame.models.db_models.operation.operation_log_model import *
+from seven_cloudapp_frame.models.mp_base_model import MPBaseModel
+from seven_cloudapp_frame.models.app_base_model import AppBaseModel
 
 
 class FrameBaseHandler(BaseApiHandler):
@@ -326,38 +329,6 @@ class FrameBaseHandler(BaseApiHandler):
         """
         return SevenHelper.create_order_id(ran)
 
-    def check_continue_request(self, handler_name, app_id, object_id, expire=100):
-        """
-        :description: 一个用户同一handler频繁请求校验，只对同用户同接口同请求参数进行限制
-        :param handler_name: handler名称
-        :param app_id: 应用标识
-        :param object_id: object_id(user_id或open_id)
-        :param expire: 间隔时间，单位毫秒
-        :return:满足频繁请求条件直接输出拦截
-        :last_editors: HuangJianYi
-        """
-        result = False, ""
-        if object_id and handler_name and app_id:
-            sign = self.get_signature_md5(self.request_params)
-            if SevenHelper.is_continue_request(f"continue_request:{handler_name}_{app_id}_{object_id}_{sign}", expire) == True:
-                result = True, f"操作太频繁,请{expire}毫秒后再试"
-        return result
-
-    def check_attack_request(self):
-        """
-        :description: 攻击请求校验
-        :return:满足条件直接拦截
-        :last_editors: HuangJianYi
-        """
-        result = False, ""
-        is_filter_attack = config.get_value("is_filter_attack", False)
-        if is_filter_attack == True and self.request_params:
-            for key in self.request_params.keys():
-                if StringHelper.is_contain_sql(self.request_params[key]) or StringHelper.is_attack(self.request_params[key]):
-                    result = True, f"参数{key}:值不合法"
-                    break
-        return result
-
     def get_signature_md5(self, request_param_dict, encrypt_key=""):
         """
         :description: 参数按照加密规则进行MD5加密
@@ -395,35 +366,6 @@ class FrameBaseHandler(BaseApiHandler):
         redis_init.sadd(cache_key, object_id)
         redis_init.expire(cache_key, 3600)
 
-    def check_request_user(self, app_id, current_limit_count, current_limit_minute=1):
-        """
-        :description: 每分钟流量UV校验
-        :param app_id: 应用标识
-        :param current_limit_count: 流量限制数
-        :param current_limit_minute: 流量限制时间，默认1分钟
-        :return: True代表满足限制条件进行拦截
-        :last_editors: HuangJianYi
-        """
-        if current_limit_count == 0:
-            return False
-        redis_init = SevenHelper.redis_init()
-        if current_limit_minute == 1:
-            cache_key = f"request_user_list_{app_id}:{str(SevenHelper.get_now_int(fmt='%Y%m%d%H%M'))}"
-        else:
-            key_list = []
-            for i in range(current_limit_minute):
-                now_minute_int = int((datetime.datetime.now() + datetime.timedelta(minutes=-i)).strftime('%Y%m%d%H%M'))
-                key = f"request_user_list_{app_id}:{str(now_minute_int)}"
-                key_list.append(key)
-            cache_key = f"request_user_list_{app_id}"
-            redis_init.sinterstore(cache_key, key_list)
-            redis_init.expire(cache_key, 3600)
-
-        if int(redis_init.scard(cache_key)) >= current_limit_count:
-            return True
-        else:
-            return False
-
     def get_app_key_secret(self):
         """
         :description: 获取app_key和app_secret
@@ -462,7 +404,8 @@ class FrameBaseHandler(BaseApiHandler):
         user_nick = self.get_param("user_nick")
         #淘宝小程序 source_app_id在本地环境返回空；在test和online环境返回后端模板id，无论在IDE还是千牛端
         if self.get_param("source_app_id") == "":
-            user_nick = config.get_value("test_user_nick")
+            test_config = config.get_value("test_config",{})
+            user_nick = test_config.get("user_nick","")
         return user_nick
 
     def get_open_id(self):
@@ -473,7 +416,8 @@ class FrameBaseHandler(BaseApiHandler):
         """
         open_id = self.get_param("open_id")
         if self.get_param("source_app_id") == "":
-            open_id = config.get_value("test_open_id")
+            test_config = config.get_value("test_config",{})
+            open_id = test_config.get("open_id","")
         return open_id
 
     def get_user_id(self):
@@ -501,7 +445,8 @@ class FrameBaseHandler(BaseApiHandler):
         source_app_id = self.get_param("source_app_id")
         #淘宝小程序 在IDE上返回前端模板id，无论哪个环境；在千牛端上返回正确的小程序id
         if source_app_id == config.get_value("client_template_id") or source_app_id == "":
-            source_app_id = config.get_value("test_source_app_id")
+            test_config = config.get_value("test_config",{})
+            source_app_id = test_config.get("source_app_id","")
         return source_app_id
 
     def get_app_id(self):
@@ -523,6 +468,21 @@ class FrameBaseHandler(BaseApiHandler):
                         app_id = app_info_dict["app_id"]
         return app_id
 
+    def get_access_token(self):
+        """
+        :description: 获取access_token
+        :return str
+        :last_editors: HuangJianYi
+        """
+        access_token = self.get_param("access_token")
+        test_config = config.get_value("test_config",{})
+        user_nick = self.get_param("user_nick")
+        if user_nick:
+            store_user_nick = user_nick.split(':')[0]
+            if store_user_nick and store_user_nick == test_config.get("user_nick",""):
+                access_token = test_config.get("access_token","")
+        return access_token
+        
     def create_operation_log(self, operation_type=1, model_name="", handler_name="", old_detail=None, update_detail=None, operate_user_id="", operate_user_name=""):
         """
         :description: 创建操作日志
@@ -567,6 +527,85 @@ class FrameBaseHandler(BaseApiHandler):
 
         operation_log_model.add_entity(operation_log)
 
+    def check_request_user(self, app_id, current_limit_count, current_limit_minute=1):
+        """
+        :description: 每分钟流量UV校验
+        :param app_id: 应用标识
+        :param current_limit_count: 流量限制数
+        :param current_limit_minute: 流量限制时间，默认1分钟
+        :return: True代表满足限制条件进行拦截
+        :last_editors: HuangJianYi
+        """
+        if current_limit_count == 0:
+            return False
+        redis_init = SevenHelper.redis_init()
+        if current_limit_minute == 1:
+            cache_key = f"request_user_list_{app_id}:{str(SevenHelper.get_now_int(fmt='%Y%m%d%H%M'))}"
+        else:
+            key_list = []
+            for i in range(current_limit_minute):
+                now_minute_int = int((datetime.datetime.now() + datetime.timedelta(minutes=-i)).strftime('%Y%m%d%H%M'))
+                key = f"request_user_list_{app_id}:{str(now_minute_int)}"
+                key_list.append(key)
+            cache_key = f"request_user_list_{app_id}"
+            redis_init.sinterstore(cache_key, key_list)
+            redis_init.expire(cache_key, 3600)
+
+        if int(redis_init.scard(cache_key)) >= current_limit_count:
+            return True
+        else:
+            return False
+
+    def check_continue_request(self, handler_name, app_id, object_id, expire=100):
+        """
+        :description: 一个用户同一handler频繁请求校验，只对同用户同接口同请求参数进行限制
+        :param handler_name: handler名称
+        :param app_id: 应用标识
+        :param object_id: object_id(user_id或open_id)
+        :param expire: 间隔时间，单位毫秒
+        :return:满足频繁请求条件直接输出拦截
+        :last_editors: HuangJianYi
+        """
+        result = False, ""
+        if object_id and handler_name and app_id:
+            sign = self.get_signature_md5(self.request_params)
+            if SevenHelper.is_continue_request(f"continue_request:{handler_name}_{app_id}_{object_id}_{sign}", expire) == True:
+                result = True, f"操作太频繁,请{expire}毫秒后再试"
+        return result
+
+    def check_attack_request(self):
+        """
+        :description: 攻击请求校验
+        :return:满足条件直接拦截
+        :last_editors: HuangJianYi
+        """
+        result = False, ""
+        is_filter_attack = config.get_value("is_filter_attack", False)
+        if is_filter_attack == True and self.request_params:
+            for key in self.request_params.keys():
+                if StringHelper.is_contain_sql(self.request_params[key]) or StringHelper.is_attack(self.request_params[key]):
+                    result = True, f"参数{key}:值不合法"
+                    break
+        return result
+
+    def check_handler_power(self):
+        """
+        :description: 校验是否有权限访问接口
+        :return:True有False没有
+        :last_editors: HuangJianYi
+        """
+        result = True
+        if self.request_params and self.request_params.get("app_id",""):
+            server_power_config = config.get_value("server_power_config", {})
+            power_codes = server_power_config.get(self.__class__.__name__,"")
+            if power_codes:
+                app_base_model = AppBaseModel(context=self.context)
+                app_info_dict = app_base_model.get_app_info_dict(self.request_params.get("app_id",""))
+                if app_info_dict:
+                    mp_base_model = MPBaseModel(context=self.context)
+                    result = mp_base_model.check_middle_power(app_info_dict["store_user_nick"], app_info_dict["project_code"], power_codes)
+        return result
+
     def business_process_executing(self):
         """
         :description: 执行前事件
@@ -644,7 +683,12 @@ class ClientBaseHandler(FrameBaseHandler):
 
                 #每分钟流量UV计数,用于登录接口限制登录
                 self.add_request_user(str(dict_param["app_id"]), str(dict_param["open_id"]))
-
+            
+            # 校验是否有权限，有才能访问接口
+            if not self.check_handler_power():
+                self.response_json_error("no_power", "没有权限操作")
+                self.finish()
+                return
         except Exception as ex:
             if not hasattr(self, "request_code"):
                 self.request_code = UUIDHelper.get_uuid()
@@ -915,3 +959,5 @@ def filter_check_params_sign(is_check=True, no_check_params=None):
         return wrapper
 
     return check_params
+
+
