@@ -30,8 +30,9 @@ class LeftNavigationHandler(ClientBaseHandler):
         :last_editors: HuangJianYi
         """
         app_base_model = AppBaseModel(context=self)
+        access_token = self.get_access_token()
         app_key, app_secret = self.get_app_key_secret()
-        invoke_result_data = app_base_model.get_left_navigation(self.get_user_nick(), self.get_param("access_token"), app_key, app_secret, self.get_param("app_id"))
+        invoke_result_data = app_base_model.get_left_navigation(self.get_user_nick(), access_token, app_key, app_secret, self.get_param("app_id"))
         if invoke_result_data.success == False:
             return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
         return self.response_json_success(invoke_result_data.data)
@@ -187,8 +188,8 @@ class CmsInfoListHandler(ClientBaseHandler):
             order_by = invoke_result_data.data["order_by"] if invoke_result_data.data.__contains__("order_by") else "id desc"
             field = invoke_result_data.data["field"] if invoke_result_data.data.__contains__("field") else "*"
         cms_base_model = CmsBaseModel(context=self)
-        page_list, total = self.business_process_executed(cms_base_model.get_cms_info_list(place_id=place_id, page_size=page_size, page_index=page_index, order_by=order_by, field=field, app_id=app_id, act_id=act_id, is_cache=False), ref_params={})
-        page_info = PageInfo(page_index, page_size, total, self.business_process_executed(page_list, ref_params={}))
+        page_info = cms_base_model.get_cms_info_list(place_id=place_id, page_size=page_size, page_index=page_index, order_by=order_by, field=field, app_id=app_id, act_id=act_id, is_cache=False)
+        page_info.data = self.business_process_executed(page_info.data, ref_params={})
         return self.response_json_success(page_info)
 
 
