@@ -111,7 +111,7 @@ class PrizeOrderListHandler(ClientBaseHandler):
         create_date_start = self.get_param("create_date_start")
         create_date_end = self.get_param("create_date_end")
         order_by = self.get_param("order_by","create_date desc")
-        is_search_roster = self.get_param("is_search_roster", 0)
+        is_search_roster = self.get_param_int("is_search_roster", 0)
         if is_search_roster == 0:
             is_search_roster = False
         else:
@@ -257,7 +257,7 @@ class UpdatePrizeOrderStatusHandler(ClientBaseHandler):
         invoke_result_data = self.business_process_executed(invoke_result_data, ref_params)
         if invoke_result_data.success ==False:
             return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
-        return self.response_json_success()
+        return self.response_json_success(invoke_result_data.data)
 
 
 class ImportPrizeOrderHandler(ClientBaseHandler):
