@@ -2,12 +2,13 @@
 """
 :Author: HuangJianYi
 :Date: 2021-07-15 11:54:54
-@LastEditTime: 2022-01-22 11:44:56
+@LastEditTime: 2022-03-10 14:29:36
 @LastEditors: HuangJianYi
 :description: 常用帮助类
 """
 from seven_framework import *
 from seven_framework.redis import *
+from seven_cloudapp_frame.libs.customize.redis_helper import RedisExHelper
 from emoji import unicode_codes
 import random
 import datetime
@@ -27,13 +28,7 @@ class SevenHelper:
         :return: redis_cli
         :last_editors: HuangJianYi
         """
-        host = config.get_value("redis")["host"]
-        port = config.get_value("redis")["port"]
-        if not db:
-            db = config.get_value("redis")["db"]
-        password = config.get_value("redis")["password"]
-        redis_cli = RedisHelper.redis_init(host, port, db, password, config_dict=config_dict, decode_responses=decode_responses)
-        return redis_cli
+        return RedisExHelper.init(db, config_dict, decode_responses)
 
     @classmethod
     def is_continue_request(self, cache_key, expire=500):
@@ -47,11 +42,11 @@ class SevenHelper:
         if config.get_value("is_pressure_test",False): #是否进行压力测试
             return False
         redis_init = self.redis_init()
-        post_value = redis_init.get(cache_key)
-        if post_value == None:
-            redis_init.set(cache_key, 10, px=expire)
-            return False
-        return True
+        post_value = redis_init.incr(cache_key,1)
+        redis_init.pexpire(cache_key,expire)
+        if post_value > 1:
+            return True
+        return False
 
     @classmethod
     def redis_check_llen(self,queue_name,queue_lenth=100):
@@ -62,12 +57,7 @@ class SevenHelper:
          :return: bool False-代表达到长度限制，进行拦截
          :last_editors: HuangJianYi
          """
-        redis_init = self.redis_init()
-        list_len = redis_init.llen(queue_name)
-        if int(list_len) >= int(queue_lenth):
-            return True
-        else:
-            return False
+        return RedisExHelper.check_llen(queue_name, queue_lenth)
 
     @classmethod
     def redis_lpush(self, queue_name, value, expire):
@@ -79,9 +69,7 @@ class SevenHelper:
          :return:
          :last_editors: HuangJianYi
          """
-        redis_init = self.redis_init()
-        redis_init.lpush(queue_name, json.dumps(value))
-        redis_init.expire(queue_name,expire)
+        RedisExHelper.lpush(queue_name, value, expire)
 
     @classmethod
     def redis_lpop(self, queue_name):
@@ -91,8 +79,7 @@ class SevenHelper:
          :return: 
          :last_editors: HuangJianYi
          """
-        result = self.redis_init().lpop(queue_name)
-        return result
+        return RedisExHelper.lpop(queue_name)
 
     @classmethod
     def redis_acquire_lock(self, lock_name, acquire_time=3, time_out=4):
@@ -104,19 +91,7 @@ class SevenHelper:
         :return 分布式锁是否获得（True获得False未获得）和解锁钥匙（释放锁时需传入才能解锁成功）
         :last_editors: HuangJianYi
         """
-        identifier = str(uuid.uuid4())
-        end = time.time() + acquire_time
-        lock = "lock:" + lock_name
-        redis_init = self.redis_init()
-        while time.time() < end:
-            if redis_init.setnx(lock, identifier):
-                # 给锁设置超时时间, 防止进程崩溃导致其他进程无法获取锁
-                redis_init.expire(lock, time_out)
-                return True,identifier
-            if redis_init.ttl(lock) == -1 or redis_init.ttl(lock) == None:
-                redis_init.expire(lock, time_out)
-            time.sleep(0.001)
-        return False,""
+        return RedisExHelper.acquire_lock(lock_name, acquire_time, time_out)
 
     @classmethod
     def redis_release_lock(self, lock_name, identifier):
@@ -127,24 +102,7 @@ class SevenHelper:
         :return bool
         :last_editors: HuangJianYi
         """
-        lock = "lock:" + lock_name
-        redis_init = self.redis_init()
-        pip = redis_init.pipeline(True)
-        try:
-            pip.watch(lock)
-            lock_value = redis_init.get(lock)
-            if not lock_value:
-                return True
-            if lock_value == identifier:
-                pip.multi()
-                pip.delete(lock)
-                pip.execute()
-                return True
-            pip.unwatch()
-            return False
-        except Exception:
-            pip.unwatch()
-            return False
+        return RedisExHelper.release_lock(lock_name, identifier)
 
     @classmethod
     def merge_dict_list(self, source_dict_list, source_key, merge_dict_list, merge_key, merge_columns_names='', exclude_merge_columns_names=''):
