@@ -7,6 +7,7 @@
 @Description: 
 """
 import re
+import datetime
 
 class StringHelper:
     """
@@ -93,3 +94,47 @@ class StringHelper:
             return True
         else:
             return False
+    
+    @classmethod
+    def check_under_age(self, card_id):
+        """
+        :description: 根据身份证号校验是否未成年
+        :param card_id:身份证号
+        :return:True已成年False未成年
+        :last_editors: HuangJianYi
+        """
+        result = True
+        if len(card_id) == 18:
+            birthday_dict = self.get_birthday(card_id)
+            birthday_year = birthday_dict["year"]
+            birthday_month = birthday_dict["month"]
+            birthday_day = birthday_dict["day"]
+            now_time = datetime.datetime.today()
+            #获取今日日期
+            today = int(str(now_time.month) + str(now_time.day))
+            if now_time.day < 10:
+                today = int(str(now_time.month) + '0' + str(now_time.day))
+            #如果今日日期超过生日 则年龄为年份相减，否则年份相减再减1
+            age = 0
+            if today - int(birthday_month + birthday_day) > 0:
+                age = now_time.year - int(birthday_year)
+            else:
+                age = now_time.year - int(birthday_year) - 1
+            if age < 18:
+                result = False
+        return result
+
+    @classmethod
+    def get_birthday(self, card_id):
+        """
+        :description: 根据身份证号获取生日
+        :param card_id:身份证号
+        :return:字典
+        :last_editors: HuangJianYi
+        """
+        birthday_dict = {"year":0,"month":0,"day":0}
+        if len(card_id) == 18:
+            birthday_dict["year"] = card_id[6:10]
+            birthday_dict["month"] = card_id[10:12]
+            birthday_dict["day"] = card_id[12:14]
+        return birthday_dict
