@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-08-19 09:23:14
-@LastEditTime: 2022-01-10 13:57:25
+@LastEditTime: 2022-03-04 15:33:47
 @LastEditors: HuangJianYi
 @Description: 
 """
@@ -82,7 +82,7 @@ class WeChatHelper:
     @classmethod
     def get_access_token(self, grant_type="client_credential",app_id="", app_secret=""):
         """
-        :description:access_token 是小程序的全局唯一调用凭据，开发者调用小程序支付时需要使用 access_token。access_token 的有效期为 2 个小时，需要定时刷新 access_token，重复获取会导致之前一次获取的 access_token 的有效期缩短为 5 分钟。
+        :description:access_token 是小程序的全局唯一调用凭据，开发者调用小程序支付时需要使用 access_token。access_token 的有效期为 2 个小时，需要定时刷新 access_token，重复获取会导致之前一次获取的 access_token 的有效期缩短为 5 分钟。建议开发者使用中控服务器统一获取和刷新 access_token，其他业务逻辑服务器所使用的 access_token 均来自于该中控服务器，不应该各自去刷新，否则容易造成冲突，导致 access_token 覆盖而影响业务；
         :param grant_type: 获取access_token 时值为 client_credential
         :param app_id:app_id
         :param app_secret:app_secret
@@ -99,7 +99,7 @@ class WeChatHelper:
             'grant_type': grant_type,
         }
         response = None
-        redis_init = SevenHelper.redis_init()
+        redis_init = SevenHelper.redis_init(config_dict=config.get_value("platform_redis"))
         redis_key = f"wechat_access_token:{str(app_id)}"
         try:
             access_token = redis_init.get(redis_key)
@@ -154,21 +154,59 @@ class WeChatHelper:
                 "templateId": template_id,
                 "miniprogramState": miniprogram_state
                 }
-            respone = requests.post(url=requset_url,params={'access_token': invoke_result_data.data},data=json.dumps(param, ensure_ascii=False).encode('utf-8'))
-            respone_data = SevenHelper.json_loads(respone.text)
-            if respone_data.__contains__("errcode") and respone_data["errcode"] != 0:
+            response = requests.post(requset_url, data=json.dumps(param, ensure_ascii=False).encode('utf-8'), headers={'Content-Type': 'application/json'})
+            response_data = SevenHelper.json_loads(response.text)
+            if response_data.__contains__("errcode") and response_data["errcode"] != 0:
                 invoke_result_data.success = False
-                invoke_result_data.error_code = respone_data["errcode"]
-                invoke_result_data.error_message = respone_data["errmsg"]
+                invoke_result_data.error_code = response_data["errcode"]
+                invoke_result_data.error_message = response_data["errmsg"]
                 return invoke_result_data
         except Exception as ex:
-            self.logger_error.error("【send_template_message】" + traceback.format_exc())
+            self.logger_error.error("【发送订阅消息】" + traceback.format_exc())
             invoke_result_data.success = False
             invoke_result_data.error_code = "exception"
             invoke_result_data.error_message = traceback.format_exc()
             return invoke_result_data
         return invoke_result_data
 
+    @classmethod
+    def get_user_phonenumber(self, code ,app_id="", app_secret=""):
+        """
+        :description:code换取用户手机号。 每个code只能使用一次，code的有效期为5min
+        :param code: 手机号获取凭证
+        :param app_id:app_id
+        :param app_secret:app_secret
+        :return: 
+        :last_editors: HuangJianYi
+        """
+        if not code:
+            invoke_result_data.success = False
+            invoke_result_data.error_code = "param_error"
+            invoke_result_data.error_message = "code无效，请升级微信版本到8.0.16以上"
+            return invoke_result_data
+        invoke_result_data = self.get_access_token(app_id=app_id, app_secret=app_secret)
+        if invoke_result_data.success == False:
+            return invoke_result_data
+        access_token = invoke_result_data.data
+        try:
+            requset_url = 'https://api.weixin.qq.com/wxa/business/getuserphonenumber?access_token=' + access_token
+            param = {'code': code}
+            response = requests.post(requset_url, data=json.dumps(param, ensure_ascii=False).encode('utf-8'), headers={'Content-Type': 'application/json'})
+            response_data = SevenHelper.json_loads(response.text)
+            if response_data.__contains__("errcode") and response_data["errcode"] != 0:
+                invoke_result_data.success = False
+                invoke_result_data.error_code = response_data["errcode"]
+                invoke_result_data.error_message = response_data["errmsg"]
+                return invoke_result_data
+            invoke_result_data.data = response_data["phone_info"]
+            return invoke_result_data
+        except Exception as ex:
+            self.logger_error.error("【授权手机号】" + traceback.format_exc())
+            invoke_result_data.success = False
+            invoke_result_data.error_code = "exception"
+            invoke_result_data.error_message = "授权手机号失败"
+            return invoke_result_data
+
     @classmethod
     def decrypt_data_by_code(self, open_id, code, encrypted_Data, iv, app_id="", app_secret=""):
         """
