@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-11-26 10:22:44
-@LastEditTime: 2022-01-13 14:50:51
+@LastEditTime: 2022-02-25 14:14:48
 @LastEditors: HuangJianYi
 @Description: 
 """
@@ -19,21 +19,17 @@ class CmsBaseModel():
         self.context = context
         self.logging_link_error = logging_error
         self.logging_link_info = logging_info
-    
-    def _delete_cms_info_dependency_key(self, place_id):
+
+    def _delete_cms_info_dependency_key(self, place_id, delay_delete_time=0.1):
         """
         :description: 删除位置信息依赖建
         :param place_id: 位置标识
         :param act_id: 活动标识
+        :param delay_delete_time: 延迟删除时间，传0则不进行延迟
         :return: 
         :last_editors: HuangJianYi
         """
-        try:
-            redis_init = SevenHelper.redis_init()
-            if place_id:
-                redis_init.delete(f"cms_info_list:placeid_{place_id}")
-        except Exception as ex:
-            pass
+        CmsInfoModel().delete_dependency_key(f"cms_info_list:placeid_{place_id}", delay_delete_time)
 
     def save_cms_info(self, place_id, cms_id, app_id, act_id, info_title, simple_title, simple_title_url, info_type, info_summary, info_tag, info_mark, target_url, min_pic, mid_pic, max_pic, info_data, pic_collect_json, sort_index, is_release, i1, i2, i3, i4, s1, s2, s3, s4):
         """
@@ -74,7 +70,7 @@ class CmsBaseModel():
             invoke_result_data.error_code = "param_error"
             invoke_result_data.error_message = "参数不能为空或等于0"
             return invoke_result_data
-
+        old_cms_info = None
         cms_info = None
         is_add = False
         cms_info_model = CmsInfoModel(context=self.context)
@@ -130,7 +126,7 @@ class CmsBaseModel():
         invoke_result_data.data = result
         self._delete_cms_info_dependency_key(place_id)
         return invoke_result_data
-    
+
     def get_cms_info_list(self, place_id, page_size, page_index, order_by="id desc",field="*", app_id="", act_id=0, is_cache=True):
         """
         :description: 位置信息列表
@@ -163,4 +159,3 @@ class CmsBaseModel():
             page_list, total = cms_info_model.get_dict_page_list(field=field, page_index=page_index, page_size=page_size, where=condition, group_by="", order_by=order_by,params=params)
         page_info = PageInfo(page_index, page_size, total, page_list)
         return page_info
-        
\ No newline at end of file
