@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-11-24 09:36:39
-@LastEditTime: 2022-02-10 11:23:15
+@LastEditTime: 2022-03-01 17:50:17
 @LastEditors: HuangJianYi
 @Description: ERP控制台业务模型(用于跟遁甲系统对接，推送订单和回写物流) 需在配置文件加 armor_url 和 armor_sign_key对应的值
 """
@@ -48,15 +48,14 @@ class ErpConsoleModel():
         push_url = config.get_value("armor_url") + "/api/new_order"
         sign_key = config.get_value("armor_sign_key", "")
 
-        prize_order_model = PrizeOrderModel()
-        prize_roster_model = PrizeRosterModel()
-        erp_relation_model = ErpRelationModel()
-
         print(f"{TimeHelper.get_now_format_time()} 推送订单队列{mod_value}启动")
 
         while True:
             try:
                 time.sleep(0.1)
+                prize_order_model = PrizeOrderModel()
+                prize_roster_model = PrizeRosterModel()
+                erp_relation_model = ErpRelationModel()
                 now_date = TimeHelper.get_now_format_time()
                 if mod_count == 1:
                     erp_relation_list = erp_relation_model.get_dict_list("is_release=1 and %s>sync_date and start_date<=%s and end_date>=%s", order_by="sync_date asc", limit="100", params=[TimeHelper.add_minutes_by_format_time(minute=-10), now_date, now_date])
@@ -218,6 +217,7 @@ class ErpConsoleModel():
                                         params = [express_no, express_company, delivery_time, modify_date, order_no]
                                         prize_order_model.update_table(update_sql, "order_no=%s", params=params)
                                         prize_roster_model.update_table("logistics_status=1", "app_id=%s and order_no=%s", params=[erp_relation_dict["app_id"], order_no])
+                                        self.process_order_pull_executed(order_info_dict)
                                     else:
                                         update_sql = "sync_status=2,sync_date=%s,sync_result=%s"
                                         params = [modify_date, "拉取订单失败", order_no]
@@ -261,6 +261,7 @@ class ErpConsoleModel():
                                                         params = [express_no, express_company, delivery_time, modify_date, order_no]
                                                         prize_order_model.update_table(update_sql, "order_no=%s", params=params)
                                                         prize_roster_model.update_table("logistics_status=1", "app_id=%s and order_no=%s", params=[erp_relation_dict["app_id"], order_no])
+                                                        self.process_order_pull_executed(data)
                                                     else:
                                                         update_sql = "sync_status=2,sync_date=%s,sync_result=%s"
                                                         params = [modify_date, "拉取订单失败", order_no]
@@ -271,4 +272,12 @@ class ErpConsoleModel():
                 else:
                     time.sleep(60)
             except Exception as ex:
-                time.sleep(5)
\ No newline at end of file
+                time.sleep(5)
+
+    def process_order_pull_executed(self, order_info_dict):
+        """
+        :description: 拉取订单执行后事件
+        :param order_info_dict: 订单信息字典
+        :return: 
+        :last_editors: HuangJianYi
+        """
