@@ -20,6 +20,28 @@ class FrameBaseModel():
     def __init__(self, context):
         self.context = context
 
+    def score_algorithm_to_score(self, weight):
+        """
+        :description: 分数算法，获取分数 = 权重 * 分数因子 + 时间极大值  - 当前时间
+        :param weight:权重值
+        :return: 分数
+        :last_editors: HuangJianYi
+        """
+        score_fator = 1_000_000_000 #分数因子
+        max_timestamp = 2_000_000_000 #时间极大值，秒级别
+        score = weight * score_fator + max_timestamp - TimeHelper.get_now_timestamp()
+        return score
+
+    def score_algorithm_to_weight(self, score):
+        """
+        :description: 分数算法，获取分数对应的权重值
+        :param score:分数
+        :return: 权重值
+        :last_editors: HuangJianYi
+        """
+        score_fator = 1_000_000_000
+        return int(score/score_fator)
+
     def lottery_algorithm_chance(self, prize_list, field_name="chance"):
         """
         :description: 抽奖算法（概率）
@@ -267,7 +289,7 @@ class FrameBaseModel():
         invoke_result_data.data["request_queue_name"] = request_queue_name
         return invoke_result_data
 
-    def business_process_executed(self,act_id,module_id,user_id,handler_name,acquire_lock_name="",identifier="",request_queue_name=""):
+    def business_process_executed(self,act_id,module_id,user_id,handler_name,acquire_lock_name="",identifier="",request_queue_name="",source_object_id=""):
         """
         :description: 业务执行后事件，调用了业务执行前事件需要调用当前方法
         :param act_id:活动标识
@@ -277,10 +299,14 @@ class FrameBaseModel():
         :param acquire_lock_name:分布式锁名称
         :param identifier:分布式锁标识
         :param request_queue_name:请求队列名称
+        :param source_object_id:来源对象标识
         :return:
         :last_editors: HuangJianYi
         """
-        SevenHelper.redis_init().delete(f"request_business_executing:{handler_name}_{act_id}_{module_id}_{user_id}")
+        continue_request_key = f"request_business_executing:{handler_name}_{act_id}_{module_id}_{user_id}"
+        if source_object_id:
+            continue_request_key += f"_{source_object_id}"
+        SevenHelper.redis_init().delete(continue_request_key)
         if acquire_lock_name and identifier:
             SevenHelper.redis_release_lock(acquire_lock_name,identifier)
         if request_queue_name:
