@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-08-02 14:26:29
-@LastEditTime: 2022-01-13 14:56:01
+@LastEditTime: 2022-02-25 14:17:50
 @LastEditors: HuangJianYi
 @Description: 
 """
@@ -22,19 +22,15 @@ class PriceBaseModel():
         self.logging_link_error = logging_error
         self.logging_link_info = logging_info
 
-    def _delete_price_gear_dependency_key(self,act_id):
+    def _delete_price_gear_dependency_key(self, act_id, delay_delete_time=0.1):
         """
         :description: 删除价格档位依赖建
         :param act_id: 活动标识
+        :param delay_delete_time: 延迟删除时间，传0则不进行延迟
         :return: 
         :last_editors: HuangJianYi
         """
-        try:
-            redis_init = SevenHelper.redis_init()
-            if act_id:
-                redis_init.delete(f"price_gear_list:actid_{act_id}")
-        except Exception as ex:
-            pass
+        PriceGearModel().delete_dependency_key(f"price_gear_list:actid_{act_id}", delay_delete_time)
 
     def save_price_gear(self,app_id,act_id,price_gear_id,relation_type,price_gear_name,price_gear_pic,price,goods_id,sku_id,remark=""):
         """
