@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-08-04 13:41:15
-@LastEditTime: 2022-01-13 14:56:31
+@LastEditTime: 2022-02-25 14:18:45
 @LastEditors: HuangJianYi
 @Description: 
 """
@@ -22,22 +22,22 @@ class PrizeBaseModel():
         self.logging_link_error = logging_error
         self.logging_link_info = logging_info
 
-    def _delete_act_prize_dependency_key(self,act_id,prize_id):
+    def _delete_act_prize_dependency_key(self, act_id, prize_id, delay_delete_time=0.1):
         """
         :description: 删除活动奖品依赖建
         :param act_id: 活动标识
         :param prize_id: 奖品标识
+        :param delay_delete_time: 延迟删除时间，传0则不进行延迟
         :return: 
         :last_editors: HuangJianYi
         """
-        try:
-            redis_init = SevenHelper.redis_init()
-            if prize_id:
-                redis_init.delete(f"act_prize:prizeid_{prize_id}")
-            if act_id:
-                redis_init.delete(f"act_prize_list:actid_{act_id}")
-        except Exception as ex:
-            pass
+        dependency_key_list = []
+        if prize_id:
+            dependency_key_list.append(f"act_prize:prizeid_{prize_id}")
+        if act_id:
+            dependency_key_list.append(f"act_prize_list:actid_{act_id}")
+        ActPrizeModel().delete_dependency_key(dependency_key_list,delay_delete_time)
+
 
     def get_act_prize_dict(self,prize_id,is_cache=True,is_filter=True):
         """
