@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-07-26 09:39:08
-@LastEditTime: 2022-01-13 14:57:43
+@LastEditTime: 2022-02-28 11:53:29
 @LastEditors: HuangJianYi
 @Description: 
 """
@@ -49,8 +49,8 @@ class StatBaseModel(FrameBaseModel):
 
         stat_process_ways = config.get_value("stat_process_ways","mysql")
         if stat_process_ways == "mysql":
-            sub_table = SevenHelper.get_sub_table(act_id,config.get_value("stat_sub_table_count",0))
-            stat_queue_model = StatQueueModel(sub_table=sub_table, context=self.context)
+            sub_table_config = config.get_value("sub_table_config", {})
+            stat_queue_model = StatQueueModel(sub_table=SevenHelper.get_sub_table(act_id, sub_table_config.get("stat_queue_num", 0)), context=self.context)
             stat_queue_model.add_entity(stat_queue)
         else:
             redis_init = SevenHelper.redis_init()
@@ -84,8 +84,8 @@ class StatBaseModel(FrameBaseModel):
 
         stat_process_ways = config.get_value("stat_process_ways","mysql")
         if stat_process_ways == "mysql":
-            sub_table = SevenHelper.get_sub_table(act_id,config.get_value("stat_sub_table_count",0))
-            stat_queue_model = StatQueueModel(sub_table=sub_table, context=self.context)
+            sub_table_config = config.get_value("sub_table_config", {})
+            stat_queue_model = StatQueueModel(sub_table=SevenHelper.get_sub_table(act_id, sub_table_config.get("stat_queue_num", 0)), context=self.context)
             return stat_queue_model.add_list(stat_queue_list)
         else:
             redis_init = SevenHelper.redis_init()
