@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-07-22 11:10:20
-@LastEditTime: 2022-02-24 13:34:14
+@LastEditTime: 2022-02-25 14:27:39
 @LastEditors: HuangJianYi
 @Description: 
 """
@@ -52,17 +52,16 @@ class UserBaseModel(FrameBaseModel):
         """
         return f"user_black:{act_id}_{user_id}"
 
-    def _delete_user_black_cache(self, act_id, user_id):
+    def _delete_user_black_cache(self, act_id, user_id, delay_delete_time=0.1):
         """
         :description: 删除用户黑名单缓存
         :param act_id：活动标识
         :param user_id：用户标识
+        :param delay_delete_time: 延迟删除时间，传0则不进行延迟
         :return: 
         :last_editors: HuangJianYi
         """
-        cache_key = self.get_user_black_dependency_key(act_id, user_id)
-        redis_init = SevenHelper.redis_init()
-        redis_init.delete(cache_key)
+        UserBlackModel().delete_dependency_key(self.get_user_black_dependency_key(act_id, user_id),delay_delete_time)
 
     def get_user_info_dependency_key(self, act_id, id_md5, open_id=""):
         """
@@ -78,17 +77,16 @@ class UserBaseModel(FrameBaseModel):
         else:
             return f"user_info:actid_{act_id}_openid_{open_id}"
 
-    def _delete_user_info_cache(self, act_id, id_md5):
+    def _delete_user_info_cache(self, act_id, id_md5, delay_delete_time=0.1):
         """
         :description: 删除用户信息缓存
         :param act_id：活动标识
         :param id_md5：用户md5标识
+        :param delay_delete_time: 延迟删除时间，传0则不进行延迟
         :return: 
         :last_editors: HuangJianYi
         """
-        cache_key = self.get_user_info_dependency_key(act_id, id_md5)
-        redis_init = SevenHelper.redis_init()
-        redis_init.delete(cache_key)
+        UserInfoModel().delete_dependency_key(self.get_user_info_dependency_key(act_id, id_md5),delay_delete_time)
 
     def get_user_info_dict(self, app_id, act_id, user_id, open_id="", is_cache=True):
         """
